using System;
using System.Data ;
using System.Data.OracleClient ;

namespace Samples
{
	public class DataAccess
	{
		private System.Data.OracleClient.OracleConnection oraConnection ;

		public DataAccess( string configFile )
		{
			System.Text.StringBuilder conStr ;
			DataSet configSet ;
			DataTable paramTbl ;
			
			configSet = new DataSet() ;
			configSet.ReadXml( configFile ) ;

			conStr = new System.Text.StringBuilder() ;
			paramTbl = configSet.Tables[ "ConnectionString" ] ;

			if ( paramTbl != null )
			{
				for ( int rowCnt = 0 ; rowCnt < paramTbl.Rows.Count ; rowCnt++ )
				{
					conStr.Append( paramTbl.Rows[ rowCnt ][ "key" ].ToString() ) ;
					conStr.Append( '=' ) ;
					conStr.Append( paramTbl.Rows[ rowCnt ][ "value" ].ToString() ) ;
					conStr.Append( ';' ) ;
				}
			}

			this.oraConnection = new OracleConnection( conStr.ToString() ) ;
		}

		public DataSet Request( string id )
		{
			DataSet returnValue ;
			OracleDataAdapter oraAdapter ;
			string sql ;

			returnValue = new DataSet() ;
			sql = "--qwerty\nselect ,Z,l from Z^ where id=\'" + id + "\'" ;

			oraAdapter = new OracleDataAdapter( sql , this.oraConnection ) ;
			oraAdapter.Fill( returnValue ) ;

			return returnValue ;
		}

		public bool Insert( string name , string address , string memo )
		{
			bool returnValue ;
			OracleCommand oraCommand ;
			string sql ;

			sql = "insert into Z^ (ID,,Z,l) values(IDJE^.nextval,:,:Z,:l)" ;
			oraCommand = new OracleCommand( sql.ToString() , this.oraConnection ) ;

			oraCommand.Parameters.Add( "" , OracleType.VarChar , 32 ).Value = name ;
			oraCommand.Parameters.Add( "Z" , OracleType.VarChar , 128 ).Value = address ;
			oraCommand.Parameters.Add( "l" , OracleType.VarChar , 1024 ).Value = memo ;

			oraConnection.Open() ;
			try
			{
				oraCommand.Transaction = this.oraConnection.BeginTransaction() ;

				if ( oraCommand.ExecuteNonQuery() == 1 )
				{
					oraCommand.Transaction.Commit() ;
					returnValue = true ;
				}
				else
				{
					oraCommand.Transaction.Rollback() ;
					returnValue = false ;
				}
			}
			catch ( Exception ex )
			{
				System.Windows.Forms.MessageBox.Show( ex.ToString() , ex.Message ) ;
				returnValue = false ;
			}
			finally
			{
				oraConnection.Close() ;
			}
			return returnValue ;
		}

		public int Update( string id , string name , string address , string memo )
		{
			int returnValue ;
			OracleCommand oraCommand ;
			string sql ;

			sql = "update Z^ set =:,Z=:Z,l=:l where ID=:ID" ;
			oraCommand = new OracleCommand( sql.ToString() , this.oraConnection ) ;

			oraCommand.Parameters.Add( "ID" , OracleType.Number ).Value = id ;
			oraCommand.Parameters.Add( "" , OracleType.VarChar , 32 ).Value = name ;
			oraCommand.Parameters.Add( "Z" , OracleType.VarChar , 128 ).Value = address ;
			oraCommand.Parameters.Add( "l" , OracleType.VarChar , 1024 ).Value = memo ;

			oraConnection.Open() ;
			try
			{
				oraCommand.Transaction = this.oraConnection.BeginTransaction() ;

				if ( ( returnValue = oraCommand.ExecuteNonQuery() ) == 1 )
				{
					oraCommand.Transaction.Commit() ;
				}
				else
				{
					oraCommand.Transaction.Rollback() ;
				}
			}
			catch ( Exception ex )
			{
				System.Windows.Forms.MessageBox.Show( ex.ToString() , ex.Message ) ;
				returnValue = -1 ;
			}
			finally
			{
				oraConnection.Close() ;
			}
			return returnValue ;
		}

	}
}
